# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: versions_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import versions_common_pb2 as versions__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16versions_service.proto\x12\x1c\x61rmonik.api.grpc.v1.versions\x1a\x15versions_common.proto2\x83\x01\n\x08Versions\x12w\n\x0cListVersions\x12\x31.armonik.api.grpc.v1.versions.ListVersionsRequest\x1a\x32.armonik.api.grpc.v1.versions.ListVersionsResponse\"\x00\x42\x1f\xaa\x02\x1c\x41rmonik.Api.Grpc.V1.Versionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'versions_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\034Armonik.Api.Grpc.V1.Versions'
  _globals['_VERSIONS']._serialized_start=80
  _globals['_VERSIONS']._serialized_end=211
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: partitions_common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17partitions_common.proto\x12\x1e\x61rmonik.api.grpc.v1.partitions\x1a\x14sort_direction.proto\"\xa8\x02\n\x0cPartitionRaw\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1c\n\x14parent_partition_ids\x18\x02 \x03(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x03\x12\x0f\n\x07pod_max\x18\x04 \x01(\x03\x12]\n\x11pod_configuration\x18\x07 \x03(\x0b\x32\x42.armonik.api.grpc.v1.partitions.PartitionRaw.PodConfigurationEntry\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x03\x12\x10\n\x08priority\x18\x06 \x01(\x03\x1a\x37\n\x15PodConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"k\n\x0ePartitionField\x12P\n\x13partition_raw_field\x18\x01 \x01(\x0e\x32\x31.armonik.api.grpc.v1.partitions.PartitionRawFieldH\x00\x42\x07\n\x05\x66ield\"\xea\x03\n\x15ListPartitionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12L\n\x06\x66ilter\x18\x03 \x01(\x0b\x32<.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Filter\x12H\n\x04sort\x18\x04 \x01(\x0b\x32:.armonik.api.grpc.v1.partitions.ListPartitionsRequest.Sort\x1a\x89\x01\n\x06\x46ilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13parent_partition_id\x18\x02 \x01(\t\x12\x14\n\x0cpod_reserved\x18\x03 \x01(\x05\x12\x0f\n\x07pod_max\x18\x04 \x01(\x05\x12\x1d\n\x15preemption_percentage\x18\x05 \x01(\x05\x12\x10\n\x08priority\x18\x06 \x01(\x05\x1a\x8b\x01\n\x04Sort\x12=\n\x05\x66ield\x18\x01 \x01(\x0b\x32..armonik.api.grpc.v1.partitions.PartitionField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x8a\x01\n\x16ListPartitionsResponse\x12@\n\npartitions\x18\x01 \x03(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x13GetPartitionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"W\n\x14GetPartitionResponse\x12?\n\tpartition\x18\x01 \x01(\x0b\x32,.armonik.api.grpc.v1.partitions.PartitionRaw*\x9a\x02\n\x11PartitionRawField\x12#\n\x1fPARTITION_RAW_FIELD_UNSPECIFIED\x10\x00\x12\x1a\n\x16PARTITION_RAW_FIELD_ID\x10\x01\x12,\n(PARTITION_RAW_FIELD_PARENT_PARTITION_IDS\x10\x02\x12$\n PARTITION_RAW_FIELD_POD_RESERVED\x10\x03\x12\x1f\n\x1bPARTITION_RAW_FIELD_POD_MAX\x10\x04\x12-\n)PARTITION_RAW_FIELD_PREEMPTION_PERCENTAGE\x10\x05\x12 \n\x1cPARTITION_RAW_FIELD_PRIORITY\x10\x06\x42!\xaa\x02\x1e\x41rmonik.Api.Grpc.V1.Partitionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'partitions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\036Armonik.Api.Grpc.V1.Partitions'
  _PARTITIONRAW_PODCONFIGURATIONENTRY._options = None
  _PARTITIONRAW_PODCONFIGURATIONENTRY._serialized_options = b'8\001'
  _globals['_PARTITIONRAWFIELD']._serialized_start=1248
  _globals['_PARTITIONRAWFIELD']._serialized_end=1530
  _globals['_PARTITIONRAW']._serialized_start=82
  _globals['_PARTITIONRAW']._serialized_end=378
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_start=323
  _globals['_PARTITIONRAW_PODCONFIGURATIONENTRY']._serialized_end=378
  _globals['_PARTITIONFIELD']._serialized_start=380
  _globals['_PARTITIONFIELD']._serialized_end=487
  _globals['_LISTPARTITIONSREQUEST']._serialized_start=490
  _globals['_LISTPARTITIONSREQUEST']._serialized_end=980
  _globals['_LISTPARTITIONSREQUEST_FILTER']._serialized_start=701
  _globals['_LISTPARTITIONSREQUEST_FILTER']._serialized_end=838
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_start=841
  _globals['_LISTPARTITIONSREQUEST_SORT']._serialized_end=980
  _globals['_LISTPARTITIONSRESPONSE']._serialized_start=983
  _globals['_LISTPARTITIONSRESPONSE']._serialized_end=1121
  _globals['_GETPARTITIONREQUEST']._serialized_start=1123
  _globals['_GETPARTITIONREQUEST']._serialized_end=1156
  _globals['_GETPARTITIONRESPONSE']._serialized_start=1158
  _globals['_GETPARTITIONRESPONSE']._serialized_end=1245
# @@protoc_insertion_point(module_scope)



from . import objects_pb2 as _objects_pb2
from . import sort_direction_pb2 as _sort_direction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationRawField(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    APPLICATION_RAW_FIELD_UNSPECIFIED: _ClassVar[ApplicationRawField]
    APPLICATION_RAW_FIELD_NAME: _ClassVar[ApplicationRawField]
    APPLICATION_RAW_FIELD_VERSION: _ClassVar[ApplicationRawField]
    APPLICATION_RAW_FIELD_NAMESPACE: _ClassVar[ApplicationRawField]
    APPLICATION_RAW_FIELD_SERVICE: _ClassVar[ApplicationRawField]
APPLICATION_RAW_FIELD_UNSPECIFIED: ApplicationRawField
APPLICATION_RAW_FIELD_NAME: ApplicationRawField
APPLICATION_RAW_FIELD_VERSION: ApplicationRawField
APPLICATION_RAW_FIELD_NAMESPACE: ApplicationRawField
APPLICATION_RAW_FIELD_SERVICE: ApplicationRawField

class ApplicationRaw(_message.Message):
    __slots__ = ["name", "version", "namespace", "service"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    NAMESPACE_FIELD_NUMBER: _ClassVar[int]
    SERVICE_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    namespace: str
    service: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., namespace: _Optional[str] = ..., service: _Optional[str] = ...) -> None: ...

class ApplicationField(_message.Message):
    __slots__ = ["application_field"]
    APPLICATION_FIELD_FIELD_NUMBER: _ClassVar[int]
    application_field: ApplicationRawField
    def __init__(self, application_field: _Optional[_Union[ApplicationRawField, str]] = ...) -> None: ...

class ListApplicationsRequest(_message.Message):
    __slots__ = ["page", "page_size", "filter", "sort"]
    class Filter(_message.Message):
        __slots__ = ["name", "version", "namespace", "service"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        VERSION_FIELD_NUMBER: _ClassVar[int]
        NAMESPACE_FIELD_NUMBER: _ClassVar[int]
        SERVICE_FIELD_NUMBER: _ClassVar[int]
        name: str
        version: str
        namespace: str
        service: str
        def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ..., namespace: _Optional[str] = ..., service: _Optional[str] = ...) -> None: ...
    class Sort(_message.Message):
        __slots__ = ["fields", "direction"]
        FIELDS_FIELD_NUMBER: _ClassVar[int]
        DIRECTION_FIELD_NUMBER: _ClassVar[int]
        fields: _containers.RepeatedCompositeFieldContainer[ApplicationField]
        direction: _sort_direction_pb2.SortDirection
        def __init__(self, fields: _Optional[_Iterable[_Union[ApplicationField, _Mapping]]] = ..., direction: _Optional[_Union[_sort_direction_pb2.SortDirection, str]] = ...) -> None: ...
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    page: int
    page_size: int
    filter: ListApplicationsRequest.Filter
    sort: ListApplicationsRequest.Sort
    def __init__(self, page: _Optional[int] = ..., page_size: _Optional[int] = ..., filter: _Optional[_Union[ListApplicationsRequest.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListApplicationsRequest.Sort, _Mapping]] = ...) -> None: ...

class ListApplicationsResponse(_message.Message):
    __slots__ = ["applications", "page", "page_size", "total"]
    APPLICATIONS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    applications: _containers.RepeatedCompositeFieldContainer[ApplicationRaw]
    page: int
    page_size: int
    total: int
    def __init__(self, applications: _Optional[_Iterable[_Union[ApplicationRaw, _Mapping]]] = ..., page: _Optional[int] = ..., page_size: _Optional[int] = ..., total: _Optional[int] = ...) -> None: ...

class CountTasksByStatusRequest(_message.Message):
    __slots__ = ["name", "version"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    name: str
    version: str
    def __init__(self, name: _Optional[str] = ..., version: _Optional[str] = ...) -> None: ...

class CountTasksByStatusResponse(_message.Message):
    __slots__ = ["status"]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    status: _containers.RepeatedCompositeFieldContainer[_objects_pb2.StatusCount]
    def __init__(self, status: _Optional[_Iterable[_Union[_objects_pb2.StatusCount, _Mapping]]] = ...) -> None: ...



from grpc import Channel

from ..common import Task
from ..protogen.client.tasks_service_pb2_grpc import TasksStub
from ..protogen.common.tasks_common_pb2 import GetTaskRequest, GetTaskResponse


class ArmoniKTasks:
    def __init__(self, grpc_channel: Channel):
        """ Tasks service client

        Args:
            grpc_channel: gRPC channel to use
        """
        self._client = TasksStub(grpc_channel)

    def get_task(self, task_id: str) -> Task:
        """Get task information from task id

        Args:
            task_id: Id of the task

        Returns:
            Task object with the information
        """
        task_response: GetTaskResponse = self._client.GetTask(GetTaskRequest(task_id=task_id))
        return Task.from_message(task_response.task)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from . import result_status_pb2 as _result_status_pb2
from . import sort_direction_pb2 as _sort_direction_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResultRawField(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    RESULT_RAW_FIELD_UNSPECIFIED: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_SESSION_ID: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_NAME: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_OWNER_TASK_ID: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_STATUS: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_CREATED_AT: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_COMPLETED_AT: _ClassVar[ResultRawField]
    RESULT_RAW_FIELD_RESULT_ID: _ClassVar[ResultRawField]
RESULT_RAW_FIELD_UNSPECIFIED: ResultRawField
RESULT_RAW_FIELD_SESSION_ID: ResultRawField
RESULT_RAW_FIELD_NAME: ResultRawField
RESULT_RAW_FIELD_OWNER_TASK_ID: ResultRawField
RESULT_RAW_FIELD_STATUS: ResultRawField
RESULT_RAW_FIELD_CREATED_AT: ResultRawField
RESULT_RAW_FIELD_COMPLETED_AT: ResultRawField
RESULT_RAW_FIELD_RESULT_ID: ResultRawField

class ResultRaw(_message.Message):
    __slots__ = ["session_id", "name", "owner_task_id", "status", "created_at", "completed_at", "result_id"]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_TASK_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    COMPLETED_AT_FIELD_NUMBER: _ClassVar[int]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    name: str
    owner_task_id: str
    status: _result_status_pb2.ResultStatus
    created_at: _timestamp_pb2.Timestamp
    completed_at: _timestamp_pb2.Timestamp
    result_id: str
    def __init__(self, session_id: _Optional[str] = ..., name: _Optional[str] = ..., owner_task_id: _Optional[str] = ..., status: _Optional[_Union[_result_status_pb2.ResultStatus, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., result_id: _Optional[str] = ...) -> None: ...

class ResultField(_message.Message):
    __slots__ = ["result_raw_field"]
    RESULT_RAW_FIELD_FIELD_NUMBER: _ClassVar[int]
    result_raw_field: ResultRawField
    def __init__(self, result_raw_field: _Optional[_Union[ResultRawField, str]] = ...) -> None: ...

class ListResultsRequest(_message.Message):
    __slots__ = ["page", "page_size", "filter", "sort"]
    class Filter(_message.Message):
        __slots__ = ["session_id", "name", "owner_task_id", "status", "created_after", "created_before", "completed_after", "completed_before", "wait_for_data_after", "wait_for_data_before", "result_id"]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        OWNER_TASK_ID_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        CREATED_AFTER_FIELD_NUMBER: _ClassVar[int]
        CREATED_BEFORE_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_AFTER_FIELD_NUMBER: _ClassVar[int]
        COMPLETED_BEFORE_FIELD_NUMBER: _ClassVar[int]
        WAIT_FOR_DATA_AFTER_FIELD_NUMBER: _ClassVar[int]
        WAIT_FOR_DATA_BEFORE_FIELD_NUMBER: _ClassVar[int]
        RESULT_ID_FIELD_NUMBER: _ClassVar[int]
        session_id: str
        name: str
        owner_task_id: str
        status: _result_status_pb2.ResultStatus
        created_after: _timestamp_pb2.Timestamp
        created_before: _timestamp_pb2.Timestamp
        completed_after: _timestamp_pb2.Timestamp
        completed_before: _timestamp_pb2.Timestamp
        wait_for_data_after: _timestamp_pb2.Timestamp
        wait_for_data_before: _timestamp_pb2.Timestamp
        result_id: str
        def __init__(self, session_id: _Optional[str] = ..., name: _Optional[str] = ..., owner_task_id: _Optional[str] = ..., status: _Optional[_Union[_result_status_pb2.ResultStatus, str]] = ..., created_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., created_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., completed_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., wait_for_data_after: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., wait_for_data_before: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., result_id: _Optional[str] = ...) -> None: ...
    class Sort(_message.Message):
        __slots__ = ["field", "direction"]
        FIELD_FIELD_NUMBER: _ClassVar[int]
        DIRECTION_FIELD_NUMBER: _ClassVar[int]
        field: ResultField
        direction: _sort_direction_pb2.SortDirection
        def __init__(self, field: _Optional[_Union[ResultField, _Mapping]] = ..., direction: _Optional[_Union[_sort_direction_pb2.SortDirection, str]] = ...) -> None: ...
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    SORT_FIELD_NUMBER: _ClassVar[int]
    page: int
    page_size: int
    filter: ListResultsRequest.Filter
    sort: ListResultsRequest.Sort
    def __init__(self, page: _Optional[int] = ..., page_size: _Optional[int] = ..., filter: _Optional[_Union[ListResultsRequest.Filter, _Mapping]] = ..., sort: _Optional[_Union[ListResultsRequest.Sort, _Mapping]] = ...) -> None: ...

class ListResultsResponse(_message.Message):
    __slots__ = ["results", "page", "page_size", "total"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    PAGE_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ResultRaw]
    page: int
    page_size: int
    total: int
    def __init__(self, results: _Optional[_Iterable[_Union[ResultRaw, _Mapping]]] = ..., page: _Optional[int] = ..., page_size: _Optional[int] = ..., total: _Optional[int] = ...) -> None: ...

class GetResultRequest(_message.Message):
    __slots__ = ["result_id"]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    result_id: str
    def __init__(self, result_id: _Optional[str] = ...) -> None: ...

class GetResultResponse(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: ResultRaw
    def __init__(self, result: _Optional[_Union[ResultRaw, _Mapping]] = ...) -> None: ...

class GetOwnerTaskIdRequest(_message.Message):
    __slots__ = ["session_id", "result_id"]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    result_id: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, session_id: _Optional[str] = ..., result_id: _Optional[_Iterable[str]] = ...) -> None: ...

class GetOwnerTaskIdResponse(_message.Message):
    __slots__ = ["result_task", "session_id"]
    class MapResultTask(_message.Message):
        __slots__ = ["result_id", "task_id"]
        RESULT_ID_FIELD_NUMBER: _ClassVar[int]
        TASK_ID_FIELD_NUMBER: _ClassVar[int]
        result_id: str
        task_id: str
        def __init__(self, result_id: _Optional[str] = ..., task_id: _Optional[str] = ...) -> None: ...
    RESULT_TASK_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    result_task: _containers.RepeatedCompositeFieldContainer[GetOwnerTaskIdResponse.MapResultTask]
    session_id: str
    def __init__(self, result_task: _Optional[_Iterable[_Union[GetOwnerTaskIdResponse.MapResultTask, _Mapping]]] = ..., session_id: _Optional[str] = ...) -> None: ...

class CreateResultsMetaDataRequest(_message.Message):
    __slots__ = ["results", "session_id"]
    class ResultCreate(_message.Message):
        __slots__ = ["name"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        name: str
        def __init__(self, name: _Optional[str] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[CreateResultsMetaDataRequest.ResultCreate]
    session_id: str
    def __init__(self, results: _Optional[_Iterable[_Union[CreateResultsMetaDataRequest.ResultCreate, _Mapping]]] = ..., session_id: _Optional[str] = ...) -> None: ...

class CreateResultsMetaDataResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ResultRaw]
    def __init__(self, results: _Optional[_Iterable[_Union[ResultRaw, _Mapping]]] = ...) -> None: ...

class CreateResultsRequest(_message.Message):
    __slots__ = ["results", "session_id"]
    class ResultCreate(_message.Message):
        __slots__ = ["name", "data"]
        NAME_FIELD_NUMBER: _ClassVar[int]
        DATA_FIELD_NUMBER: _ClassVar[int]
        name: str
        data: bytes
        def __init__(self, name: _Optional[str] = ..., data: _Optional[bytes] = ...) -> None: ...
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[CreateResultsRequest.ResultCreate]
    session_id: str
    def __init__(self, results: _Optional[_Iterable[_Union[CreateResultsRequest.ResultCreate, _Mapping]]] = ..., session_id: _Optional[str] = ...) -> None: ...

class CreateResultsResponse(_message.Message):
    __slots__ = ["results"]
    RESULTS_FIELD_NUMBER: _ClassVar[int]
    results: _containers.RepeatedCompositeFieldContainer[ResultRaw]
    def __init__(self, results: _Optional[_Iterable[_Union[ResultRaw, _Mapping]]] = ...) -> None: ...

class UploadResultDataRequest(_message.Message):
    __slots__ = ["id", "data_chunk"]
    class ResultIdentifier(_message.Message):
        __slots__ = ["session_id", "result_id"]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        RESULT_ID_FIELD_NUMBER: _ClassVar[int]
        session_id: str
        result_id: str
        def __init__(self, session_id: _Optional[str] = ..., result_id: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    DATA_CHUNK_FIELD_NUMBER: _ClassVar[int]
    id: UploadResultDataRequest.ResultIdentifier
    data_chunk: bytes
    def __init__(self, id: _Optional[_Union[UploadResultDataRequest.ResultIdentifier, _Mapping]] = ..., data_chunk: _Optional[bytes] = ...) -> None: ...

class UploadResultDataResponse(_message.Message):
    __slots__ = ["result"]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: ResultRaw
    def __init__(self, result: _Optional[_Union[ResultRaw, _Mapping]] = ...) -> None: ...

class ResultsServiceConfigurationResponse(_message.Message):
    __slots__ = ["data_chunk_max_size"]
    DATA_CHUNK_MAX_SIZE_FIELD_NUMBER: _ClassVar[int]
    data_chunk_max_size: int
    def __init__(self, data_chunk_max_size: _Optional[int] = ...) -> None: ...

class DownloadResultDataRequest(_message.Message):
    __slots__ = ["session_id", "result_id"]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    result_id: str
    def __init__(self, session_id: _Optional[str] = ..., result_id: _Optional[str] = ...) -> None: ...

class DownloadResultDataResponse(_message.Message):
    __slots__ = ["data_chunk"]
    DATA_CHUNK_FIELD_NUMBER: _ClassVar[int]
    data_chunk: bytes
    def __init__(self, data_chunk: _Optional[bytes] = ...) -> None: ...

class DeleteResultsDataRequest(_message.Message):
    __slots__ = ["session_id", "result_id"]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    result_id: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, session_id: _Optional[str] = ..., result_id: _Optional[_Iterable[str]] = ...) -> None: ...

class DeleteResultsDataResponse(_message.Message):
    __slots__ = ["session_id", "result_id"]
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    RESULT_ID_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    result_id: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, session_id: _Optional[str] = ..., result_id: _Optional[_Iterable[str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ..common import tasks_common_pb2 as tasks__common__pb2


class TasksStub(object):
    """*
    Service for handling tasks.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/ListTasks',
                request_serializer=tasks__common__pb2.ListTasksRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.ListTasksResponse.FromString,
                )
        self.ListTasksRaw = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/ListTasksRaw',
                request_serializer=tasks__common__pb2.ListTasksRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.ListTasksRawResponse.FromString,
                )
        self.GetTask = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/GetTask',
                request_serializer=tasks__common__pb2.GetTaskRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.GetTaskResponse.FromString,
                )
        self.CancelTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/CancelTasks',
                request_serializer=tasks__common__pb2.CancelTasksRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.CancelTasksResponse.FromString,
                )
        self.GetResultIds = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/GetResultIds',
                request_serializer=tasks__common__pb2.GetResultIdsRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.GetResultIdsResponse.FromString,
                )
        self.CountTasksByStatus = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/CountTasksByStatus',
                request_serializer=tasks__common__pb2.CountTasksByStatusRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.CountTasksByStatusResponse.FromString,
                )
        self.SubmitTasks = channel.unary_unary(
                '/armonik.api.grpc.v1.tasks.Tasks/SubmitTasks',
                request_serializer=tasks__common__pb2.SubmitTasksRequest.SerializeToString,
                response_deserializer=tasks__common__pb2.SubmitTasksResponse.FromString,
                )


class TasksServicer(object):
    """*
    Service for handling tasks.
    """

    def ListTasks(self, request, context):
        """*
        Get a tasks list using pagination, filters and sorting.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTasksRaw(self, request, context):
        """*
        Get a tasks list using pagination, filters and sorting with complete metada.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTask(self, request, context):
        """*
        Get a task by its id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelTasks(self, request, context):
        """*
        Cancel tasks using ids.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetResultIds(self, request, context):
        """*
        Get ids of the result that tasks should produce.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CountTasksByStatus(self, request, context):
        """*
        Get count from tasks status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SubmitTasks(self, request, context):
        """*
        Create tasks metadata and submit task for processing.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TasksServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTasks,
                    request_deserializer=tasks__common__pb2.ListTasksRequest.FromString,
                    response_serializer=tasks__common__pb2.ListTasksResponse.SerializeToString,
            ),
            'ListTasksRaw': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTasksRaw,
                    request_deserializer=tasks__common__pb2.ListTasksRequest.FromString,
                    response_serializer=tasks__common__pb2.ListTasksRawResponse.SerializeToString,
            ),
            'GetTask': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTask,
                    request_deserializer=tasks__common__pb2.GetTaskRequest.FromString,
                    response_serializer=tasks__common__pb2.GetTaskResponse.SerializeToString,
            ),
            'CancelTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelTasks,
                    request_deserializer=tasks__common__pb2.CancelTasksRequest.FromString,
                    response_serializer=tasks__common__pb2.CancelTasksResponse.SerializeToString,
            ),
            'GetResultIds': grpc.unary_unary_rpc_method_handler(
                    servicer.GetResultIds,
                    request_deserializer=tasks__common__pb2.GetResultIdsRequest.FromString,
                    response_serializer=tasks__common__pb2.GetResultIdsResponse.SerializeToString,
            ),
            'CountTasksByStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.CountTasksByStatus,
                    request_deserializer=tasks__common__pb2.CountTasksByStatusRequest.FromString,
                    response_serializer=tasks__common__pb2.CountTasksByStatusResponse.SerializeToString,
            ),
            'SubmitTasks': grpc.unary_unary_rpc_method_handler(
                    servicer.SubmitTasks,
                    request_deserializer=tasks__common__pb2.SubmitTasksRequest.FromString,
                    response_serializer=tasks__common__pb2.SubmitTasksResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'armonik.api.grpc.v1.tasks.Tasks', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Tasks(object):
    """*
    Service for handling tasks.
    """

    @staticmethod
    def ListTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/ListTasks',
            tasks__common__pb2.ListTasksRequest.SerializeToString,
            tasks__common__pb2.ListTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTasksRaw(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/ListTasksRaw',
            tasks__common__pb2.ListTasksRequest.SerializeToString,
            tasks__common__pb2.ListTasksRawResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTask(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/GetTask',
            tasks__common__pb2.GetTaskRequest.SerializeToString,
            tasks__common__pb2.GetTaskResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CancelTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/CancelTasks',
            tasks__common__pb2.CancelTasksRequest.SerializeToString,
            tasks__common__pb2.CancelTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetResultIds(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/GetResultIds',
            tasks__common__pb2.GetResultIdsRequest.SerializeToString,
            tasks__common__pb2.GetResultIdsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CountTasksByStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/CountTasksByStatus',
            tasks__common__pb2.CountTasksByStatusRequest.SerializeToString,
            tasks__common__pb2.CountTasksByStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SubmitTasks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/armonik.api.grpc.v1.tasks.Tasks/SubmitTasks',
            tasks__common__pb2.SubmitTasksRequest.SerializeToString,
            tasks__common__pb2.SubmitTasksResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
